## Python module for interacting with Dolibarr API
With containerization and micro services being a prevailing architecture this module
should be useful to accomplish many application needs via standard or k8s cronjobs.
This also allows for any python driven application (frontend or backend) to interact
easily with Dolibarr.

### Goals
*  Create a library for consuming all core functions of API
*  Create helper functions for common uses

### Implementation status
* Check the implementation_status.csv file to see which Dolibarr API endpoints has been implemented here in dolibarrpy
